import React from 'react'

import Table from 'grommet/components/Table';
import TableRow from 'grommet/components/TableRow';
import Section from 'grommet/components/Section';
import Heading from 'grommet/components/Heading';

const renderRow = (team, name, wide) => {
  if (wide) {
    return (
      <TableRow>
        <td>{name}</td>
        <td>{team['prob'].toFixed(2)}</td>
        <td>{team['mean']}</td>
        <td>{team['std']}</td>
        <td>{team['5%']}</td>
        <td>{team['50%']}</td>
        <td>{team['95%']}</td>
      </TableRow>
    )
  } else {
    return (
      <TableRow>
        <td>{team['prob'].toFixed(2)}</td>
        <td>{team['mean']}</td>
      </TableRow>
    )
  }
}

const MatchupTable = (props) => {
  const { team1, team2, responsive } = props
  const wide = (responsive === 'multiple')

  return (
    <Section>
      <Heading tag='h3' align='center'>
        Team Breakdown
      </Heading>
      <Table responsive={false}>
        <thead>
          {(wide) ?
            <tr>
              <th>Team</th>
              <th>Pr(Win)</th>
              <th>Proj</th>
              <th>Std Dev</th>
              <th>5%</th>
              <th>50%</th>
              <th>95%</th>
            </tr>
          :
            <tr>
              <th>Pr(Win)</th>
              <th>Proj</th>
            </tr>
          }
        </thead>
        <tbody>
          {renderRow(team1, 'Team 1', wide)}
          {renderRow(team2, 'Team 2', wide)}
        </tbody>
      </Table>
    </Section>
  )
}


export default MatchupTable
